@@ -80,7 +80,7 @@ def put_text_on_image(image, text, coord=(5, 5), color=(255, 0, 0)):
 
 
 def stack_and_plot_images(images, texts=None, margin=5, margin_value=0, rows=-1, ax=None, base_size=3):
-    """ Stack and plot a list of images. Returns ax, stacked_images """
+    """Stack and plot a list of images. Returns ax, stacked_images"""
     import matplotlib.pyplot as plt
 
     cols, rows = get_plot_cols_rows(len(images), rows)
@@ -203,6 +203,8 @@ def make_gradcam_heatmap(model, processed_image, layer_name="auto", pred_index=N
     # This is the gradient of the output neuron (top predicted or chosen)
     # with regard to the output feature map of the last conv layer
     grads = tape.gradient(class_channel, last_conv_layer_output)
+    grads = tf.cast(grads, preds.dtype)
+    last_conv_layer_output = tf.cast(last_conv_layer_output, preds.dtype)
 
     if use_v2:
         # gradcam_plus_plus from: https://github.com/keisen/tf-keras-vis/blob/master/tf_keras_vis/gradcam_plus_plus.py
